package com.ruoyi.change.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.change.mapper.TbAssetReturnMapper;
import com.ruoyi.change.domain.TbAssetReturn;
import com.ruoyi.change.service.ITbAssetReturnService;

/**
 * 资产归还Service业务层处理
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@Service
public class TbAssetReturnServiceImpl implements ITbAssetReturnService 
{
    @Autowired
    private TbAssetReturnMapper tbAssetReturnMapper;

    /**
     * 查询资产归还
     * 
     * @param id 资产归还主键
     * @return 资产归还
     */
    @Override
    public TbAssetReturn selectTbAssetReturnById(Long id)
    {
        return tbAssetReturnMapper.selectTbAssetReturnById(id);
    }

    /**
     * 查询资产归还列表
     * 
     * @param tbAssetReturn 资产归还
     * @return 资产归还
     */
    @Override
    public List<TbAssetReturn> selectTbAssetReturnList(TbAssetReturn tbAssetReturn)
    {
        return tbAssetReturnMapper.selectTbAssetReturnList(tbAssetReturn);
    }

    /**
     * 新增资产归还
     * 
     * @param tbAssetReturn 资产归还
     * @return 结果
     */
    @Override
    public int insertTbAssetReturn(TbAssetReturn tbAssetReturn)
    {
        return tbAssetReturnMapper.insertTbAssetReturn(tbAssetReturn);
    }

    /**
     * 修改资产归还
     * 
     * @param tbAssetReturn 资产归还
     * @return 结果
     */
    @Override
    public int updateTbAssetReturn(TbAssetReturn tbAssetReturn)
    {
        return tbAssetReturnMapper.updateTbAssetReturn(tbAssetReturn);
    }

    /**
     * 批量删除资产归还
     * 
     * @param ids 需要删除的资产归还主键
     * @return 结果
     */
    @Override
    public int deleteTbAssetReturnByIds(Long[] ids)
    {
        return tbAssetReturnMapper.deleteTbAssetReturnByIds(ids);
    }

    /**
     * 删除资产归还信息
     * 
     * @param id 资产归还主键
     * @return 结果
     */
    @Override
    public int deleteTbAssetReturnById(Long id)
    {
        return tbAssetReturnMapper.deleteTbAssetReturnById(id);
    }
}
