package com.ruoyi.change.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.change.domain.TbAssetReturn;
import com.ruoyi.change.service.ITbAssetReturnService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资产归还Controller
 * 
 * @author 原动力
 * @date 2023-05-15
 */
@RestController
@RequestMapping("/change/return")
public class TbAssetReturnController extends BaseController
{
    @Autowired
    private ITbAssetReturnService tbAssetReturnService;

    /**
     * 查询资产归还列表
     */
    @PreAuthorize("@ss.hasPermi('change:return:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbAssetReturn tbAssetReturn)
    {
        startPage();
        List<TbAssetReturn> list = tbAssetReturnService.selectTbAssetReturnList(tbAssetReturn);
        return getDataTable(list);
    }

    /**
     * 导出资产归还列表
     */
    @PreAuthorize("@ss.hasPermi('change:return:export')")
    @Log(title = "资产归还", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbAssetReturn tbAssetReturn)
    {
        List<TbAssetReturn> list = tbAssetReturnService.selectTbAssetReturnList(tbAssetReturn);
        ExcelUtil<TbAssetReturn> util = new ExcelUtil<TbAssetReturn>(TbAssetReturn.class);
        util.exportExcel(response, list, "资产归还数据");
    }

    /**
     * 获取资产归还详细信息
     */
    @PreAuthorize("@ss.hasPermi('change:return:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbAssetReturnService.selectTbAssetReturnById(id));
    }

    /**
     * 新增资产归还
     */
    @PreAuthorize("@ss.hasPermi('change:return:add')")
    @Log(title = "资产归还", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbAssetReturn tbAssetReturn)
    {
        return toAjax(tbAssetReturnService.insertTbAssetReturn(tbAssetReturn));
    }

    /**
     * 修改资产归还
     */
    @PreAuthorize("@ss.hasPermi('change:return:edit')")
    @Log(title = "资产归还", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbAssetReturn tbAssetReturn)
    {
        return toAjax(tbAssetReturnService.updateTbAssetReturn(tbAssetReturn));
    }

    /**
     * 删除资产归还
     */
    @PreAuthorize("@ss.hasPermi('change:return:remove')")
    @Log(title = "资产归还", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbAssetReturnService.deleteTbAssetReturnByIds(ids));
    }
}
